@@ -15,8 +15,9 @@ def runtime():
 
 @runtime.command(name='list', short_help="List runtime containers")
 @click.option('--scope', nargs=1,
-              help="An AND-composed string of predicates that selects the scope in which the alert will be "
-                   """applied. (like: 'host.domain = "example.com" and container.image != "alpine:latest"')""")
+              help=("An AND-composed string of predicates that selects the scope in which the alert will be "
+                    "applied. (like: 'kubernetes.namespace.name = \"example-java-app\" and "
+                    "kubernetes.deployment.name = \"example-java-app-redis\"')"))
 @click.option('--skip-policy', is_flag=True, help="No policy evaluations will be triggered for the images.")
 @click.option('--start', nargs=1, help="Start of the time range.")
 @click.option('--end', nargs=1, help="End of the time range.")
